@@ -601,8 +601,6 @@ select_new_file(GtkWidget *widget, gpointer user_data)
   choose_filename();
 
   clear_edit();
-  deletemenutree();
-  add_control_tree(gettree());
   dasher_start();
   dasher_redraw();
   dasher_pause(0,0);
@@ -958,10 +956,10 @@ timer_callback(gpointer data)
 	
 	// And call update_colours again now that we can do something useful
 	update_colours();
-	deletemenutree();
+	//	deletemenutree();
 	// And making bonobo calls from another thread is likely to lead to
 	// pain as well. It'd be nice to do this while training, but.
-	add_control_tree(gettree());
+	//	add_control_tree(gettree());
 
 	dasher_redraw();
       }
